<p>Logged in as {{loggedInUserText()}}</p>

<form autocomplete="off" novalidate>
    <button class="btn btn-default btn-xl" (click)="doLogout()"
            [disabled]="isAuthenticating">
        Logout
    </button>
</form>