<Label *ngIf="!appDetails.length" class="h1" text="No Plugins Installed"></Label>
<ScrollView>
    <WrapLayout>
        <GridLayout *ngFor="let app of appDetails"
                    rows="*,auto" columns="*" class="home-icon"
                    [nsRouterLink]="[app.resourcePath]">
            <Image row="0" col="0" src="~{{app.pluginIconPath}}"></Image>
            <Label row="1" col="0" [text]="app.title"
            class="text-center h3"> </Label>
        </GridLayout>
    </WrapLayout>
</ScrollView>