<div class="container-fluid">
    <div *ngIf="!appDetails.length" class="row"><h1>No Plugins Installed</h1></div>
    <div class="row">
        <a *ngFor="let app of appDetails"
           [routerLink]="[app.resourcePath]">
            <div class="col-lg-2 col-md-3 col-sm-4 col-xs-6 home-icon">
                <img [src]="[app.pluginIconPath]" >
                <p class="text-center">{{app.title}}</p>
            </div>
        </a>
    </div>
</div>