
<form autocomplete="off" novalidate>
    <fieldset [disabled]="isAuthenticating">
        <div class="form-group">
            <label for="userIdField">User</label>
            <select id="userIdField" class="form-control" name="userId"
                    [(ngModel)]="selectedUser.userId">
                <option [value]="user.userId" *ngFor="let user of users">
                    {{user.displayName}} ({{user.userId}})
                </option>
            </select>
        </div>
        <div class="form-group">
            <label for="passwordField">Password</label>
            <input type="password" class="form-control" id="passwordField"
                   name="password"
                   [(ngModel)]="selectedUser.password">
        </div>
    </fieldset>
    <button class="btn btn-default btn-xl" (click)="doLogin()"
            [disabled]="isAuthenticating">
        {{loginText()}}
    </button>
</form>