<div>
    <h1>Welcome to Field Switching.</h1>

    <p>Peek Field Switching allows field engineers working on the
        electricity network to electronically</p>
    <ul>
        <li>View switching instructions</li>
        <li>Receive instructions from the control room</li>
        <li>And field confirm field switching operations</li>
    </ul>
</div>


<Button class="btn btn-default"
        [routerLink]="['./joblist']">My Jobs >
</Button>
<hr>
Logged in as {{userDetails.displayName}}