<StackLayout class="p-10">

    <label class="h3 text-center" text="Welcome to"></label>
    <label class="h1 text-center" text="Field Switching"></label>
    <label class="" textWrap="true" text=
            "Peek Field Switching allows field engineers working on the
electricity network to electronically"></label>

    <label></label>
    <label class="" text="* View switching instructions"></label>
    <label class="" text="* Receive instructions from the control room"></label>
    <label class="" text="* And field confirm field switching operations"></label>
    <label></label>

    <Button text=" My Jobs > "
            [nsRouterLink]="['/peek_plugin_pof_field_switching/joblist']"></Button>


    <label class="m-t-20 text-center"
           text="Logged in as {{userDetails.displayName}}"></label>
</StackLayout>