<div class="container-fluid">
    <div class="row menu-bar" [class.bg-danger]="!vortexIsOnline">
        <!--<ul class="btn ">-->
        <!--<li role="presentation" class="dropdown">-->
        <!--<button href="#" class="btn pull-left dropdown-toggle"-->
        <!--data-toggle="dropdown" role="button"-->
        <!--aria-haspopup="true"-->
        <!--aria-expanded="false">MenuDD-->
        <!--</button>-->
        <!--<ul class="dropdown-menu">-->
        <!--<li *ngFor="let app of appDetails">-->
        <!--<a [href]="app.resourcePath">{{app.title}}</a>-->
        <!--</li>-->
        <!--</ul>-->
        <!--</li>-->
        <!--</ul>-->
        <span class="col-xs-2 col-md-2">
            <button class="btn left-button "
                    [routerLink]="['/']">Home</button>
            <button class="btn left-button"
                    *ngFor="let link of leftLinks"
                    [routerLink]="[link.resourcePath]">{{linkTitle(link)}}</button>
        </span>
        <div class="col-xs-8 col-md-8 text-center menu-title">
            <h2 class="menu-title">{{title}}</h2>
        </div>
        <span class="col-xs-2 col-md-2">
            <button class="btn pull-right right-button"
                    *ngFor="let link of rightLinks"
                    [routerLink]="[link.resourcePath]">{{linkTitle(link)}}</button>
        </span>

    </div>
</div>
