
.home-icon {
    border-radius: 8pt;
    color: black;
    font-size: 14pt;
    width: 160pt;
    height: 160pt;
    margin: 10pt;
    background-color: cornflowerblue;
}

.home-icon img {
    margin-left: auto;
    margin-right: auto;
    margin-top: 30px;
    margin-bottom: 10px;
    display: block;
    width: auto;
    height: 120px;
    border-radius: 8pt;
}
