// This file is auto generated, the git version is blank and .gitignored
import {PluginNoopClientRootModule} from "@peek-mobile/peek_plugin_noop/plugin-noop-root.module";
import {PluginPofFieldSwitchingRootModule} from "@peek-mobile/peek_plugin_pof_field_switching/plugin-pof-field-switching-root.module";
import {PluginUserRootModule} from "@peek-mobile/peek_plugin_user/plugin-user-root.module";
export const pluginRootModules = [
	PluginNoopClientRootModule,
	PluginPofFieldSwitchingRootModule,
	PluginUserRootModule
];
