// This file is auto generated, the git version is blank and .gitignored
import {PluginNoopClientRootService} from "@peek-mobile/peek_plugin_noop/plugin-noop-root.service";
import {PluginPofFieldSwitchingRootService} from "@peek-mobile/peek_plugin_pof_field_switching/plugin-pof-field-switching-root.service";
import {UserService} from "@peek-mobile/peek_plugin_user/services/user.service";
export const pluginRootServices = [
	PluginNoopClientRootService,
	PluginPofFieldSwitchingRootService,
	UserService
];
