// This file is auto generated, the git version is blank and .gitignored
export const homeLinks = [
    {
        "name": "peek_plugin_noop", 
        "pluginIconPath": "/assets/peek_plugin_noop/plugin_icon.png", 
        "resourcePath": "/peek_plugin_noop", 
        "title": "Testing Noop"
    }, 
    {
        "name": "peek_plugin_pof_field_switching", 
        "pluginIconPath": "/assets/peek_plugin_pof_field_switching/plugin_icon.png", 
        "resourcePath": "/peek_plugin_pof_field_switching", 
        "title": "Field Switching"
    }, 
    {
        "name": "peek_plugin_user", 
        "pluginIconPath": "/assets/peek_plugin_user/plugin_icon.png", 
        "resourcePath": "/peek_plugin_user", 
        "title": "Login / Logout"
    }
];
