// This file is auto generated, the git version is blank and .gitignored
export const pluginRoutes = [
    {
        path: 'peek_plugin_noop',
        loadChildren: "peek_plugin_noop/plugin-noop.module#PluginNoopClientModule"
    },
    {
        path: 'peek_plugin_pof_field_switching',
        loadChildren: "peek_plugin_pof_field_switching/plugin-pof-field-switching.module#PluginPofFieldSwitchingClientModule"
    },
    {
        path: 'peek_plugin_user',
        loadChildren: "peek_plugin_user/plugin-user.module#PluginUserModule"
    }
];
